@@ -10,8 +10,8 @@ pub mod build;
 pub use build::*;
 
 #[derive(Parser)]
-#[clap(name = "cargo")]
-#[clap(bin_name = "cargo")]
+#[clap(name = "cargo-gra")]
+#[clap(bin_name = "cargo-gra")]
 #[clap(override_usage = "cargo gra <SUBCOMMAND>")]
 struct Cargo {
     // take the self name (gra) argument provided by cargo when calling via cargo gra ...
